import { useState } from "react";
import { Route, useHistory } from "react-router";
import axios from "axios";
import Box from "@mui/material/Box";
import Alert from "@mui/material/Alert";
import MainHeader from "../components/MainHeader";
import Typography from "@mui/material/Typography";
import { TextField } from "@mui/material";
import Button from "@mui/material/Button";
import * as React from "react";
import { Redirect } from "react-router-dom";

// Page used for entering username and initializing gamerun
export default function UsernamePage() {
  const [username, setUsername] = useState("");
  const [error, setError] = useState(false);
  const [initSuccessful, setInitSuccessful] = useState(false);
  const history = useHistory();

  function handleChangeUsername(e) {
    setError(false); // hide username error msg when username is changed
    setUsername(e.target.value);
  }

  function handleStart() {
    if (username.trim().length === 0) {
      // if username is blank set error
      setError(true);
      return;
    }

    //fix
    localStorage.setItem("username", username);

    axios("http://localhost:8000/init/", {
      method: "POST",
      withCredentials: true,
      data: { username: username },
    })
      // TODO fix history, error with fetching
      .then((e) => setInitSuccessful(true));
  }
  // fix

  const errorBox = (
    <Box
      sx={{
        display: "flex",
        width: "100%",
        justifyContent: "center",
        position: "absolute",
        mt: 10,
      }}
    >
      <Alert severity="error">Nickname cannot be blank!</Alert>
    </Box>
  );

  return (
    <div>
      <MainHeader />
      {/* if username is blank, show box with error */}
      {error && errorBox}

      {/* Wrapper for centering username form */}
      <Box
        sx={{
          width: "100%",
          height: "100%",
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
        }}
      >
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
          }}
        >
          <Typography variant="h4">Enter your nickname</Typography>
          {/* Box with input TextField for username */}
          <Box
            sx={{
              display: "flex",
              justifyContent: "center",
              mt: 2,
            }}
          >
            <TextField
              id="username"
              label="Username"
              value={username}
              onChange={handleChangeUsername}
              sx={{ mr: 3 }}
              {...(error && { error: true, helperText: error })}
            />
            <Button variant="contained" size="large" onClick={handleStart}>
              Start
            </Button>
          </Box>
        </Box>
      </Box>
      {initSuccessful && <Redirect to="/play" />}
    </div>
  );
}
